# Sirex

A package to use regex functions for strings and numbers

## Usage

Sirex has many functions that help you do  regex function calls on strings  <br>
Please see the documentation for the different functions

```
from sirex import * 
sirex.count_numbers("Hell123ow 123")
```